@@ -4,9 +4,8 @@ from fsqlfly.base_handle import BaseHandler, RespCode
 from fsqlfly import settings
 
 is_login = False
-user = dict(code=200, name='flink', status='ok', currentAuthority='admin', type='password',
-            avatar='https://gw.alipayobjects.com/zos/antfincdn/XAosXuNZyF/BiazfanxmamNRoxxVxka.png',
-            token=settings.FSQLFLY_TOKEN)
+user = dict(code=200, name='admin', status='ok', currentAuthority='admin', type='password',
+            token=settings.FSQLFLY_TOKEN, success=True)
 
 
 class LoginHandler(BaseHandler):
@@ -28,4 +27,14 @@ class LoginHandler(BaseHandler):
             self.write_error(RespCode.LoginFail)
 
 
-default_handlers = [(r'/api/login', LoginHandler)]
+class LoginOutHandler(BaseHandler):
+    def get(self):
+        if self.current_user:
+            self.set_logout_status()
+            self.write_json(user)
+
+
+default_handlers = [
+    (r'/api/login', LoginHandler),
+    (r'/api/logout', LoginOutHandler),
+]
