@@ -6,7 +6,7 @@ from tornado.web import authenticated
 from logzero import logger
 from fsqlfly import settings
 from fsqlfly.base_handle import BaseHandler, RespCode
-from fsqlfly.models import Namespace, FileResource, Functions, Transform, Resource
+from fsqlfly.models import Namespace, FileResource, Functions, Transform, Resource, auto_close
 from fsqlfly.utils.strings import dict2camel, dict2underline
 from fsqlfly.utils.response import create_response
 
@@ -21,6 +21,7 @@ _MODELS = {
 
 class APICounter(BaseHandler):
     @authenticated
+    @auto_close
     def get(self):
         data = {
             "namespaceNum": Namespace.select().where(Namespace.is_deleted == False).count(),
@@ -28,12 +29,14 @@ class APICounter(BaseHandler):
             "functionNum": Functions.select().where(Functions.is_deleted == False).count(),
             "fileNum": FileResource.select().where(FileResource.is_deleted == False).count(),
             "transformNum": Transform.select().where(Transform.is_deleted == False).count(),
+            "code": 200, "success": True
         }
-        return self.write_json(create_response(data=data))
+        return self.write_json(data)
 
 
 class CRHandler(BaseHandler):
     @authenticated
+    @auto_close
     def get(self, model: str):
         if model not in _MODELS:
             return self.write_error(RespCode.APIFail)
@@ -43,6 +46,7 @@ class CRHandler(BaseHandler):
         return self.write_json(create_response(data))
 
     @authenticated
+    @auto_close
     def post(self, model: str):
         if model not in _MODELS:
             return self.write_error(RespCode.APIFail)
@@ -62,11 +66,16 @@ class CRHandler(BaseHandler):
 
 class UDHandler(BaseHandler):
     @authenticated
+    @auto_close
     def post(self, model: str, pk: int):
         if model not in _MODELS:
             return self.write_error(RespCode.APIFail)
         obj = _MODELS[model].select().where(_MODELS[model].id == pk).get()
         data = self.json_body
+        if 'name' in data:
+            if data['name'] != obj.name:
+                return self.write_error(RespCode.APIFail, msg='创建之后禁止修改名字')
+
         for k, v in dict2underline(data).items():
             if k not in ('update_at', 'create_at', 'is_deleted', 'id') and not (k.endswith('_id') and v == 0):
                 setattr(obj, k, v)
@@ -74,6 +83,7 @@ class UDHandler(BaseHandler):
         self.write_json(create_response(data=obj.to_dict()))
 
     @authenticated
+    @auto_close
     def delete(self, model: str, pk: int):
         if model not in _MODELS:
             return self.write_error(RespCode.APIFail)
