@@ -4,16 +4,17 @@ import re
 import subprocess
 import tempfile
 import yaml
-from typing import Optional
+from typing import Optional, List
 from jinja2 import Template
 from terminado.management import NamedTermManager
-from fsqlfly.settings import BASE_DIR, FSQLFLY_FLINK_BIN, logger
+from fsqlfly.settings import FSQLFLY_UPLOAD_DIR, FSQLFLY_FLINK_BIN, logger
 from fsqlfly.models import Transform, Namespace, Resource, Functions
 from fsqlfly import settings
+from fsqlfly.utils.strings import get_job_header
 
 
-def _create_config_from_resource(resource: Resource, **kwargs) -> dict:
-    data = yaml.load(handle_template(resource.yaml, **kwargs), yaml.FullLoader)
+def _create_config_from_resource(resource: Resource, args: dict) -> dict:
+    data = yaml.load(handle_template(text=resource.yaml, args=args), yaml.FullLoader)
     data['name'] = resource.name
     return data
 
@@ -32,15 +33,19 @@ def _get_functions() -> list:
     return res
 
 
-def _get_jar() -> str:
+def _get_jar() -> List[str]:
     res = []
     for f in Functions.select().where(Functions.is_deleted == False).objects():
-        r_p = os.path.join(BASE_DIR, f.resource.real_path[1:])
+        r_p = os.path.join(FSQLFLY_UPLOAD_DIR, f.resource.real_path[1:])
         res.append(r_p)
-    return ' '.join('-j {} '.format(x) for x in set(res))
+
+    out = []
+    for x in set(res):
+        out.extend(['-j', x])
+    return out
 
 
-def _create_config(require: str, config: Optional[str], **kwargs) -> str:
+def _create_config(require: str, config: Optional[str], args: dict) -> str:
     tables = []
     if require.strip():
         for x in require.split(','):
@@ -50,16 +55,16 @@ def _create_config(require: str, config: Optional[str], **kwargs) -> str:
                 space, name = None, x
 
             if space:
-                space = Namespace.select().where(Namespace.name == space).get()
+                space = Namespace.select().where(Namespace.name == space).first()
 
-            resource = Resource.select().where(Namespace.name == name & Namespace.namespace == space).get()
-            resource_only_name = Resource.select().where(Resource.name == name).get()
+            resource = Resource.select().where(Namespace.name == name & Resource.namespace == space).first()
+            resource_only_name = Resource.select().where(Resource.name == name).first()
             if resource is None and resource_only_name is not None:
                 resource = resource_only_name
 
-            data = _create_config_from_resource(resource, **kwargs)
+            data = _create_config_from_resource(resource, args)
             tables.append(data)
-    base_config = yaml.load(handle_template(config, **kwargs), yaml.FullLoader) if config else dict()
+    base_config = yaml.load(handle_template(config, args), yaml.FullLoader) if config else dict()
     if base_config is None:
         base_config = dict()
     if base_config.get('tables'):
@@ -74,24 +79,23 @@ def _clean(s: str) -> str:
     return re.sub(r'\[\d+(;\d+)?m?', '', s)
 
 
-def handle_template(text: str, **kwargs) -> str:
-    return Template(text).render(**kwargs)
+def handle_template(text: str, args: dict) -> str:
+    return Template(text).render(**args)
 
 
 def run_transform(transform: Transform, **kwargs) -> (bool, str):
     _, yaml_f = tempfile.mkstemp(suffix='.yaml')
     _, sql_f = tempfile.mkstemp(suffix='.sql')
 
-    yaml_conf = _create_config(transform.require, transform.yaml, **kwargs)
-    sql = handle_template(transform.sql, **kwargs)
+    yaml_conf = _create_config(require=transform.require, config=transform.yaml, args=kwargs)
+    sql = handle_template(transform.sql, kwargs)
     print(yaml_conf, file=open(yaml_f, 'w'))
     print(sql, file=open(sql_f, 'w'))
     print('q\nexit;', file=open(sql_f, 'a+'))
-    pt = '_' + kwargs['pt'] if 'pt' in kwargs else ''
     run_commands = [FSQLFLY_FLINK_BIN, 'embedded',
-                    '-s', '{}_{}.{}-'.format(transform.id, transform.name, pt),
+                    '-s', get_job_header(transform, **kwargs),
                     '--environment', yaml_f,
-                    _get_jar(),
+                    *_get_jar(),
                     '<', sql_f]
     print(' '.join(run_commands))
     try:
@@ -117,19 +121,21 @@ def run_transform(transform: Transform, **kwargs) -> (bool, str):
 
 def run_debug_transform(data: dict, manager: NamedTermManager) -> (str, str):
     _, yaml_f = tempfile.mkstemp(suffix='.yaml')
-    yaml_conf = _create_config(data.get('require', ''), data.get('yaml', ''))
+    yaml_conf = _create_config(data.get('require', ''), data.get('yaml', ''), dict())
     print(yaml_conf, file=open(yaml_f, 'w'))
-    real_sql = handle_template(data.get('sql', ''))
+    real_sql = handle_template(data.get('sql', ''), dict())
     name = manager._next_available_name()
     run_commands = [FSQLFLY_FLINK_BIN, 'embedded',
-                    '-s', '{}{}.'.format(settings.TEMP_TERMINAL_HEAD, str(name)),
+                    '-s', '{}{}'.format(settings.TEMP_TERMINAL_HEAD, str(name)),
                     '--environment', yaml_f,
-                    _get_jar()]
+                    *_get_jar()]
     logger.debug('running commands is : {}'.format(' '.join(run_commands)))
     term = manager.new_terminal(shell_command=run_commands)
+
     logger.debug('sql :{}'.format(real_sql))
     term.ptyproc.write(real_sql)
     term.term_name = name
+    setattr(term, settings.TERMINAL_OPEN_NAME, True)
+    term.run_command = ' '.join(run_commands)
     manager.terminals[name] = term
-    manager.start_reading(term)
     return name
